/* File: CoAX_IP2.java
 * Contains: The main program for bin/acp3-with-watcher
 * Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Created: June 2000
 * Updated: Mon Sep 11 13:16:23 2000 by Jeff Dalton
 * Copyright: (c) 1998, 2000, AIAI, University of Edinburgh
 */


package ix.ip2.coax;

import java.io.File;

import ix.util.*;
import ix.ip2.*;


/** The CoAX IP2 application main program. */

public class CoAX_IP2 extends IP2 {

    public static MessageInterpreter interpreter;

    public static void main(String[] argv) {

	printGreeting("CoAX IP2");

	processCommandLineArguments(argv);

	boolean useModel = Parameters.getBoolean("model", true);
	boolean useViewer = Parameters.getBoolean("viewer", true);

	File modelDirectory = new File("coax-ip2", "ProcessModels");

	// Create an object to represent the IP2 application
	agent = new CoAX_IP2();

	// No watcher.

	// Create a process model that sits between the watcher and the viewer
	// /\/ For now, we have to do this before creating the viewer,
	// /\/ so it can grab an expansion tree from the model.
	if (useModel) {
	    model = new ProcessModel();
	    model.initFromFile
		(new File(modelDirectory, "coax-process.lsp").getPath());
	}
	else {
	    model = new TrivialProcessModel();
	}

	// Create a viewer
	if (useViewer) {
	    viewer = new MainFrame();
	    ((MainFrame)viewer).vg.setModelDirectory(modelDirectory);
	}
	else
	    viewer = new TrivialViewer();

	// Connect model and viewer.
	model.setViewer(viewer);
	viewer.setProcessModel(model);

	// No watcher, just a message interpreter.  Nonetheless, we 
	// install the model as its listener.
	interpreter = new MessageInterpreter(model);

	// Init AutoTester.  /\/: Probably it ought to be an object
	AutoTester.init();

	// All command-line arguments should now have been processed.
	Parameters.checkParameterUse();

	// Start displaying the monitoring results
	model.sendFullStateDescription();

	// Monitor
	// No watcher, so we don't do watcherMainLoop();

    }

    protected void shutdown() {
	super.shutdown();
    }

    public void reset() {
	AutoTester.stopAll(); 	// do this 1st
	if (model != null) model.reset();
	interpreter.reset();
	((MainFrame)viewer).reset();
	super.reset();
	((MainFrame)viewer).handleMonitorButton();
    }

}

