/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Fri Sep 15 22:22:21 2000 by Jeff Dalton
 * Copyright: (c) 1998, AIAI, University of Edinburgh
 */

package ix.test;

import java.util.*;

import ix.icon.*;

import ix.util.*;
import ix.util.lisp.*;


/**
 * A simple example using an I-X framework, version 2.
 */

public class PicoIXTest2 extends PicoIX {

    /**
     * Main program.
     */
    public static void main(String[] argv) {

	T_IX_Component example = new T_IX_Component();

	example.addIssueHandlers(makeTestIssueHandlers());
	example.setListener(new T_IX_ComponentListener());
	example.start();

	example.newEvent
	    (new T_Issue("twice", new T_Issue("return", "hello")));

	example.newEvent
	    (new T_Issue("stop when finished"));

    }

    /**
     * Create issue handlers as "instant" subclasses of T_IssueHandler.
     */
    static Object[] makeTestIssueHandlers() {
	return new Object[] {

	    // Post an issue twice.
	    new T_IssueHandler("twice") {
		void handleIssue(T_Issue i) {
		    pushIssue((Issue)i.object);
		    pushIssue((Issue)i.object);
		}
	    },

            // Send something to the listener.
	    new T_IssueHandler("return") {
		void handleIssue(T_Issue i) {
		    component.notifyListener(i.object);
		}
	    },

	    // Stop the component.
	    new T_IssueHandler("stop when finished") {
		void handleIssue(T_Issue i) {
		    if (component.controller.issues.isEmpty())
			component.stop();
		    else
			postIssue(i); 	// go to the end of the queue
		}
	    }
	};
    }

}
