/* Author: Jeff Dalton
 * Updated: Fri Jan 19 16:45:05 2001 by Jeff Dalton
 * Copyright: (c) 2001, AIAI, University of Edinburgh
 */

package ix.util;

import java.awt.*;
import java.awt.event.*;
import java.util.*;

import ix.util.*;
import ix.util.lisp.*;

public class TextAreaFrame extends TextArea {

    TFrame frame;
    TListener listener;

    String summary;

    public TextAreaFrame(String title) {
	super();
	setBackground(Color.white);
	setFont(new Font("Courier", Font.PLAIN, DefaultFont.normal.getSize()));
	frame = new TFrame(title);
	frame.textAreaFrame = this;
	frame.add(this);
    }

    public Frame getFrame() {
	return frame;
    }

    public String getSummary() {
	return summary;
    }

    public void setListener(TListener listener) {
	this.listener = listener;
    }

    public void setText(String summary, String text) {
	this.summary = summary;
	super.setText(text);
	frame.validate();
    }

    public void setVisible(boolean b) {
	frame.setVisible(b);
    }

    static public interface TListener {
	public void textChanged();
    }

    static class TFrame extends Frame {

	TextAreaFrame textAreaFrame;

	TFrame(String title) {
	    super(title);
	    setSize(800, 400);
	    setBackground(Color.white);
	    setFont(DefaultFont.normal);
	    setLayout(new BorderLayout());

	    Panel p = new Panel();
	    add(p, BorderLayout.SOUTH);
	    p.add(new Button("Save Changes"));
	    p.add(new Button("Hide Frame"));
	}

	public boolean action(Event ev, Object arg) {
	    if (ev.target instanceof Button) {
		if (arg.equals("Save Changes")) {
		    if (textAreaFrame.listener != null)
			textAreaFrame.listener.textChanged();
		    return true;
		}
		if (arg.equals("Hide Frame")) {
		    Debug.noteln("Request to hide", this);
		    hide();
		    return true;
		}
	    }
	    return false;
	}

    }

}
