/* Author: Jeff Dalton
 * Updated: Fri Jan 19 16:44:41 2001 by Jeff Dalton
 * Copyright: (c) 2000, AIAI, University of Edinburgh
 */

package ix.view.matrix;

import java.awt.*;
import java.awt.event.*;
import java.util.*;

import ix.ip2.*;
import ix.util.*;
import ix.util.lisp.*;

public class IssueMatrix extends Panel {

    public IssueMatrix(Container parent) {
        super(new GridBagLayout());
	vmClear();
    }

    public void addIssue(String text) {
	GridBagConstraints c = new GridBagConstraints();

	// Issue description

	c.gridx = 0;
	c.gridy = GridBagConstraints.RELATIVE;
	c.weightx = 1;
	c.weighty = 1;
	c.anchor = GridBagConstraints.WEST;
	c.fill = GridBagConstraints.NONE;

	TextField tf = new TextField(text, 45);
	tf.setBackground(Color.white);
	tf.setEditable(false);
	tf.addMouseListener(mouseListener);

	add(tf, c);

	// Menu of options for handling the issue

	c.gridx = 1;
	c.fill = GridBagConstraints.HORIZONTAL;

	StringTokenizer tok = new StringTokenizer(text);
	Debug.assert(tok.hasMoreElements(), "invalid issue");
	String verb = (String)tok.nextElement();

	Choice choice = new Choice();
	choice.add("No action");
	choice.add(verb + (verb.endsWith("e") ? "d" : "ed"));

	add(choice, c);

    }

    public void addExampleIssues() {
	// addIssue("Note \"Observation 1 ...\"");
	// addIssue("Note \"Observation 2 ...\"");

	addIssue("Note \"Observation 23 Gao open-jeep N16.35 E35.28 ...\"");
	addIssue("Note \"Herd-at herd-3 N16.17 E35.04 ...\"");
	addIssue("Resolve conflict-between agent-3 agent-7 ...");
	addIssue("Reallocate observe-herd herd-3 for agent-32 ...");

	invalidate();
    }


    // We can use the same mouse listener for all of the issue TextFields.

    TextAreaFrame issueFrame = new TextAreaFrame("Issue description");

    Hashtable descriptionTable = new Hashtable();

    MouseListener mouseListener = new MouseAdapter() {
	public void mouseClicked(MouseEvent e) {
	    TextField clicked = (TextField)e.getComponent();
	    String issueText = clicked.getText();

	    Debug.noteln("User wants to look at issue", issueText);

	    String description = (String)descriptionTable.get(issueText);

	    if (description != null) {
		issueFrame.setText(issueText, description);
	    }
	    else {
		issueFrame.setText(
		   issueText,
		   "No further information vailable for issue\n" +
		   issueText);
	    }
	    issueFrame.setVisible(true);
	}
    };

    TextAreaFrame.TListener tListener = new TextAreaFrame.TListener() {
	public void textChanged() {
	    String summary = issueFrame.getSummary();
	    Debug.noteln("Changing description of", summary);
	    descriptionTable.put(summary, issueFrame.getText());
	}
    };

    { issueFrame.setListener(tListener); }

    // Only one issue can be expanded (at present), so we may as
    // well make the arrangements in a simple way.  /\/
    {
	descriptionTable.put(
	  "Note \"Observation 23 Gao open-jeep N16.35 E35.28 ...\"",

	  "Issue reference: 342\n" +
	  "Verb: Note\n" +
	  "Type: Observation\n" +
	  "Source: Coalition-observer-domain:Dartmouth-agent-001\n" +
	  "Contents:\n" +
	  "    29-SEP-2012 13:54.17 OBSERVATION 0023 VEHICLE\n" +
	  "    Observer : N16.35 E35.28\n" +
	  "    Sightline: 290 deg, 0 deg down, 2500 m\n" +
	  "    Vehicle  : Gao open jeep, heading: 180, speed: 70 km/h\n" +
	  "    Note     : 3 soldiers\n" +
	  "Comments:\n" +
	  "    Maps being gathered\n" +
	  "\n" +
	  "Options:\n" +
	  "    1. No Action\n" +
	  "    2. Noted\n"
	  );

    }


    // Some methods to make it look more like a ViewMatrix.

    public void start() {
    }

    public void vmClear() {
	removeAll();
    }

    public void statusUpdate(ProcessStatusUpdate up) {
    }

}
